@@ -16,4 +16,17 @@ def export_model_summaries(f_dict,**kwargs):
         df = f.export(dfs='model_summaries',**kwargs)
         df['Series'] = k
         forecast_info = pd.concat([forecast_info,df],ignore_index=True)
-    return forecast_info
\ No newline at end of file
+    return forecast_info
+
+def keep_smallest_first_date(*fs):
+    """ trims all passed Forecaster objects so they all have the same first date.
+    
+    Args:
+        *fs (Forecaster objects): the objects to check and trim
+
+    Returns:
+        None
+    """
+    first_date = max([min(f.current_dates) for f in fs])
+    for f in fs:
+        f.keep_smaller_history(first_date)
\ No newline at end of file
